#include <iostream>
#include <iomanip>
#include <cmath>
#include <exception>

using namespace std;


class CLogistic {
public:
	double a, s;
	double operator()(double x){
		return 1.0 / (1.0 + exp(-(x - a) / s));
	}
};

template <class TF> void TBisection(TF & f,	// Functor(double x)
	double s,				// s > 0 or s < 0 if f is increasing or decreasing, respectively.
	double c,				// c = f(Root)
	double L_b, double U_b,			// Set so that f(L_b) < c < f(U_b)   
	double & Root,				// The required value so that f(Root) = c
	double acc)				// Accuracy
{
	if ((f(L_b) - c) * (f(U_b) - c) > 0.0){
		throw  "Value error of L_b or U_b.";
	}
	do {
		double m = 0.5 * (L_b + U_b);
		double v = f(m);
		if (s * (v - c) > 0.0) {
			U_b = m;
		}
		else {
			L_b = m;
		}
	} while ((abs(U_b - L_b) >= acc * abs(U_b))
		&&
		((abs(U_b) + abs(L_b)) >= 1.0e-14)
		);
	Root = 0.5 * (L_b + U_b);
}


int main(){
	CLogistic f;
	cout << "a = ";
	cin >> f.a;
	cout << "s (> 0) = ";
	cin >> f.s;
	double U_v = 10.0;
	while (f(U_v) <= 0.75) U_v += 10.0;
	double L_v = -10.0;
	while (f(L_v) >= 0.25) L_v -= 10.0;
	double FQ1, FMed, FQ3;
	TBisection(f, 1.0, 0.25, L_v, U_v, FQ1, 1.0e-12);
	TBisection<CLogistic>(f, 1.0, 0.5, L_v, U_v, FMed, 1.0e-12);
	TBisection(f, 1.0, 0.75, L_v, U_v, FQ3, 1.0e-12);
	cout << "Q1 = " << setprecision(9) << fixed << FQ1
		<< "   Med = " << FMed
		<< "   Q3 = " << FQ3 << endl;
	
	return 0;
}
